@@ -13,7 +13,7 @@ from imagekit.models import ProcessedImageField, ImageSpecField
 
 
 class GeneralInfoConfiguration(models.Model):
-    application_name = models.CharField(max_length=50, default='App. Name')
+    application_name = models.CharField(max_length=50, default='App. Name', null=True)
 
     def imagen_logo_upload_to(self, filename) -> str:  # pragma: no cover
         random_number = random.randint(11111, 99999)
@@ -93,9 +93,9 @@ class GeneralInfoConfiguration(models.Model):
         format='PNG'
     )
 
-    address = models.TextField(max_length=200, null=True, blank=True)
-    contact_emails = models.TextField(max_length=200, null=True, blank=True)
-    attention_schedule = models.TextField(null=True, blank=True)
+    contact_emails = models.TextField(blank=True, null=True)
+    attention_schedule = models.TextField(blank=True, null=True)
+    address = models.TextField(blank=True, null=True)
     facebook = models.CharField(max_length=200, null=True, blank=True)
     whatsaap = models.CharField(max_length=200, null=True, blank=True)
     instagram = models.CharField(max_length=200, null=True, blank=True)
