@@ -16,7 +16,8 @@ from users_extended.models import ExtendedUser
 
 
 def send_registration_email(user: User, email: str):
-    subject, from_email, to = 'Validación Registro', '%s <%s>' % ('La Página', 'prueba@gmail.com'), email
+    subject, from_email, to = 'Validación Registro', '%s <%s>' % (
+        settings.SITE_NAME, settings.DEFAULT_FROM_EMAIL), email
     activation_key = decrypt(user.extended_user.registration_token)
     context = {
         "domain": settings.MAIN_DOMAIN,
@@ -52,7 +53,10 @@ def ask_restore_password_account_user(
         extended_user.registration_expiration = now + timedelta(days=2)
         extended_user.save()
 
-        subject, from_email, to = 'Validación Registro', '%s <%s>' % ('La Página', 'prueba@gmail.com'), user.email
+        subject, from_email, to = 'Validación Registro', '%s <%s>' % (
+            settings.SITE_NAME,
+            settings.DEFAULT_FROM_EMAIL
+        ), user.email
         activation_key = decrypt(extended_user.registration_token)
         context = {
             "domain": settings.MAIN_DOMAIN,
